@@ -40,6 +40,10 @@ class TestKojiTaskStateChangeStart(Base):
         "python-websocket-client-0.12.0-1.fc20.src.rpm started"
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_usernames = set(['ralph'])
     expected_packages = set([])
     expected_objects = set([
@@ -79,6 +83,10 @@ class TestKojiTaskStateChangeFail(Base):
         "python-websocket-client-0.12.0-1.fc20.src.rpm failed"
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_usernames = set(['ralph'])
     expected_packages = set([])
     expected_objects = set([
@@ -112,6 +120,10 @@ class TestKojiBuildTag(Base):
                       "f18-updates-testing-pending by bodhi")
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['stage'])
     expected_usernames = set(['ralph', 'bodhi'])
     expected_objects = set([
@@ -144,6 +156,10 @@ class TestKojiBuildUnTag(Base):
                       "untagged from f16-updates-pending by bodhi")
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['globus-gram-job-manager-sge'])
     expected_usernames = set(['ralph', 'bodhi'])
     expected_objects = set([
@@ -187,6 +203,10 @@ class TestKojiBuildStateChangeStart(Base):
     expected_subti = "ralph's eclipse-ptp-6.0.3-1.fc19 started building"
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_usernames = set(['ralph'])
     expected_packages = set(['eclipse-ptp'])
     expected_objects = set([
@@ -226,6 +246,7 @@ class TestKojiBuildStateChangeStartNoOwner(Base):
     expected_subti = "eclipse-ptp-6.0.3-1.fc19 started building"
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = expected_icon
     expected_usernames = set([])
     expected_packages = set(['eclipse-ptp'])
     expected_objects = set([
@@ -271,6 +292,10 @@ class TestKojiBuildStateChangeFail(Base):
     expected_subti = "rmattes's eclipse-ptp-6.0.3-1.fc19 failed to build (ppc)"
     expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
                      "Artwork_DesignService_koji-icon-48.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "9daff58407cf59893344b3305c6f838c?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['eclipse-ptp'])
     expected_usernames = set(['rmattes'])
     expected_objects = set([
