@@ -23,6 +23,8 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
+from common import add_doc
+
 
 class TestPkgdbACLUpdate(Base):
     """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
@@ -30,14 +32,14 @@ class TestPkgdbACLUpdate(Base):
     """
 
     expected_title = "pkgdb.acl.update"
-    expected_subti = "ralph changed ralph's 'watchbugzilla' permission on " + \
-        "python-sh (EL-6) to 'Awaiting Review'"
+    expected_subti = ("ralph changed ralph's 'watchbugzilla' permission on "
+                      "python-sh (EL-6) to 'Awaiting Review'")
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/python-sh"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['python-sh'])
     expected_usernames = set(['ralph', 'grover'])
     expected_objects = set(['python-sh/acls/EL-6/watchbugzilla/ralph'])
@@ -86,11 +88,11 @@ class TestPkgdbPackageNew(Base):
     expected_title = "pkgdb.package.new"
     expected_subti = "ralph added a new package 'php-zmq' (devel)"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph', 'lmacken'])
     expected_objects = set(['php-zmq/create'])
@@ -134,11 +136,11 @@ class TestPkgdbOwnerUpdate(Base):
     expected_title = "pkgdb.owner.update"
     expected_subti = "ralph changed owner of php-zmq (EL-6) to 'orphan'"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/owner/EL-6'])
@@ -180,11 +182,11 @@ class TestLegacyPkgdbACLRequestToggle(Base):
     expected_title = "pkgdb.acl.request.toggle"
     expected_subti = "ralph has requested 'commit' on php-zmq (EL-6)"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/acls/EL-6/commit/ralph'])
@@ -227,11 +229,11 @@ class TestLegacyPkgdbPackageUpdate(Base):
     expected_title = "pkgdb.package.update"
     expected_subti = "ralph made some updates to php-zmq"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                              "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                              "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/update'])
@@ -255,11 +257,11 @@ class TestPkgdbPackageUpdate(Base):
     expected_title = "pkgdb.package.update"
     expected_subti = "ralph made some updates to guake"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/guake"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['guake'])
     expected_usernames = set(['ralph', 'pingou'])
     expected_objects = set(['guake/update'])
@@ -304,11 +306,11 @@ class TestPkgdbBranchClone(Base):
     expected_title = "pkgdb.branch.clone"
     expected_subti = "ralph branched php-zmq f18 from devel"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/branch'])
@@ -335,11 +337,11 @@ class TestPkgdbCritpathUpdate(Base):
     """
     expected_title = "pkgdb.critpath.update"
     expected_subti = "ralph altered the critpath status for some packages"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set([])
@@ -364,11 +366,11 @@ class TestPkgdbPackageRetire(Base):
     expected_title = "pkgdb.package.retire"
     expected_subti = "ralph retired php-zmq (EL-6)!"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/retire'])
@@ -411,11 +413,11 @@ class TestPkgdbUserRemove(Base):
     expected_title = "pkgdb.acl.user.remove"
     expected_subti = "ralph removed ralph from php-zmq (EL-6, F18)"
     expected_link = "https://admin.fedoraproject.org/pkgdb/acls/name/php-zmq"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set(['php-zmq'])
     expected_usernames = set(['ralph'])
     expected_objects = set(['php-zmq/remove/ralph'])
@@ -479,11 +481,11 @@ class TestPkgdbBranchStart(Base):
     """
     expected_title = "pkgdb.branch.start"
     expected_subti = "ralph started a branch of F-19 from devel"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set()
@@ -520,11 +522,11 @@ class TestPkgdbBranchComplete(Base):
     """
     expected_title = "pkgdb.branch.complete"
     expected_subti = "ralph's branch of F-19 from devel completed"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set()
@@ -561,11 +563,11 @@ class TestPkgdbCollectionNew(Base):
     """
     expected_title = "pkgdb.collection.new"
     expected_subti = "ralph created a new collection for Fedora 19"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set()
@@ -593,13 +595,13 @@ class TestPkgdbCollectionUpdate(Base):
     publishes messages like these when an admin creates a new collection.
     """
     expected_title = "pkgdb.collection.update"
-    expected_subti = "ralph updated the following fields of the Fedora 18 " + \
-        "collection: name, version"
-    expected_icon = "https://apps.fedoraproject.org/packages/images/icons/" + \
-        "package_128x128.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph updated the following fields of the Fedora 18 "
+                      "collection: name, version")
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set()
@@ -626,5 +628,7 @@ class TestPkgdbCollectionUpdate(Base):
     }
 
 
+add_doc(locals())
+
 if __name__ == '__main__':
     unittest.main()
